read_config This will read and parse a config file

read_config(path = NULL)

Arguments

path

NULL if want to use pacakge default, user input if custom config

Value

nested list showing user configuration

Examples

if (FALSE) read_config(NULL) # \dontrun{}