R/api.R
read_config.Rd
read_config This will read and parse a config file
read_config(path = NULL)
NULL if want to use pacakge default, user input if custom config
nested list showing user configuration
if (FALSE) read_config(NULL) # \dontrun{}